package VMOMI::DistributedVirtualSwitchHostMemberHostComponentState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
